/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This code was generated by https://code.google.com/p/google-apis-client-generator/
 * (build: 2013-06-20 19:08:55 UTC)
 * on 2013-06-21 at 21:29:09 UTC 
 * Modify at your own risk.
 */

package com.google.api.services.audit;

/**
 * Service definition for Audit (v1).
 *
 * <p>
 * Lets you access user activities in your enterprise made through various applications.
 * </p>
 *
 * <p>
 * For more information about this service, see the
 * <a href="https://developers.google.com/google-apps/admin-audit/get_started" target="_blank">API Documentation</a>
 * </p>
 *
 * <p>
 * This service uses {@link AuditRequestInitializer} to initialize global parameters via its
 * {@link Builder}.
 * </p>
 *
 * @since 1.3
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public class Audit extends com.google.api.client.googleapis.services.json.AbstractGoogleJsonClient {

  // Note: Leave this static initializer at the top of the file.
  static {
    com.google.api.client.util.Preconditions.checkState(
        com.google.api.client.googleapis.GoogleUtils.MAJOR_VERSION == 1 &&
        com.google.api.client.googleapis.GoogleUtils.MINOR_VERSION >= 15,
        "You are currently running with version %s of google-api-client. " +
        "You need at least version 1.15 of google-api-client to run version " +
        "1.15.0-rc of the Enterprise Audit API library.", com.google.api.client.googleapis.GoogleUtils.VERSION);
  }

  /**
   * The default encoded root URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_ROOT_URL = "https://www.googleapis.com/";

  /**
   * The default encoded service path of the service. This is determined when the library is
   * generated and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_SERVICE_PATH = "apps/reporting/audit/v1/";

  /**
   * The default encoded base URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   */
  public static final String DEFAULT_BASE_URL = DEFAULT_ROOT_URL + DEFAULT_SERVICE_PATH;

  /**
   * Constructor.
   *
   * <p>
   * Use {@link Builder} if you need to specify any of the optional parameters.
   * </p>
   *
   * @param transport HTTP transport, which should normally be:
   *        <ul>
   *        <li>Google App Engine:
   *        {@code com.google.api.client.extensions.appengine.http.UrlFetchTransport}</li>
   *        <li>Android: {@code newCompatibleTransport} from
   *        {@code com.google.api.client.extensions.android.http.AndroidHttp}</li>
   *        <li>Java: {@link com.google.api.client.googleapis.javanet.GoogleNetHttpTransport#newTrustedTransport()}
   *        </li>
   *        </ul>
   * @param jsonFactory JSON factory, which may be:
   *        <ul>
   *        <li>Jackson: {@code com.google.api.client.json.jackson2.JacksonFactory}</li>
   *        <li>Google GSON: {@code com.google.api.client.json.gson.GsonFactory}</li>
   *        <li>Android Honeycomb or higher:
   *        {@code com.google.api.client.extensions.android.json.AndroidJsonFactory}</li>
   *        </ul>
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @since 1.7
   */
  public Audit(com.google.api.client.http.HttpTransport transport, com.google.api.client.json.JsonFactory jsonFactory,
      com.google.api.client.http.HttpRequestInitializer httpRequestInitializer) {
    this(new Builder(transport, jsonFactory, httpRequestInitializer));
  }

  /**
   * @param builder builder
   */
  Audit(Builder builder) {
    super(builder);
  }

  @Override
  protected void initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest<?> httpClientRequest) throws java.io.IOException {
    super.initialize(httpClientRequest);
  }

  /**
   * An accessor for creating requests from the Activities collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Audit audit = new Audit(...);}
   *   {@code Audit.Activities.List request = audit.activities().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Activities activities() {
    return new Activities();
  }

  /**
   * The "activities" collection of methods.
   */
  public class Activities {

    /**
     * Retrieves a list of activities for a specific customer and application.
     *
     * Create a request for the method "activities.list".
     *
     * This request holds the parameters needed by the the audit server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @param customerId Represents the customer who is the owner of target object on which action was performed.
     * @param applicationId Application ID of the application on which the event was performed.
     * @return the request
     */
    public List list(java.lang.String customerId, java.lang.Long applicationId) throws java.io.IOException {
      List result = new List(customerId, applicationId);
      initialize(result);
      return result;
    }

    public class List extends AuditRequest<com.google.api.services.audit.model.Activities> {

      private static final String REST_PATH = "{customerId}/{applicationId}";

      private final java.util.regex.Pattern CUSTOMERID_PATTERN =
          java.util.regex.Pattern.compile("C.+");

      /**
       * Retrieves a list of activities for a specific customer and application.
       *
       * Create a request for the method "activities.list".
       *
       * This request holds the parameters needed by the the audit server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
       * List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
       * called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param customerId Represents the customer who is the owner of target object on which action was performed.
       * @param applicationId Application ID of the application on which the event was performed.
       * @since 1.13
       */
      protected List(java.lang.String customerId, java.lang.Long applicationId) {
        super(Audit.this, "GET", REST_PATH, null, com.google.api.services.audit.model.Activities.class);
        this.customerId = com.google.api.client.util.Preconditions.checkNotNull(customerId, "Required parameter customerId must be specified.");
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(CUSTOMERID_PATTERN.matcher(customerId).matches(),
              "Parameter customerId must conform to the pattern " +
              "C.+");
        }
        this.applicationId = com.google.api.client.util.Preconditions.checkNotNull(applicationId, "Required parameter applicationId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(java.lang.String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(java.lang.String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(java.lang.String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(java.lang.String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(java.lang.String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(java.lang.String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /**
       * Represents the customer who is the owner of target object on which action was performed.
       */
      @com.google.api.client.util.Key
      private java.lang.String customerId;

      /** Represents the customer who is the owner of target object on which action was performed.
       */
      public java.lang.String getCustomerId() {
        return customerId;
      }

      /**
       * Represents the customer who is the owner of target object on which action was performed.
       */
      public List setCustomerId(java.lang.String customerId) {
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(CUSTOMERID_PATTERN.matcher(customerId).matches(),
              "Parameter customerId must conform to the pattern " +
              "C.+");
        }
        this.customerId = customerId;
        return this;
      }

      /** Application ID of the application on which the event was performed. */
      @com.google.api.client.util.Key
      private java.lang.Long applicationId;

      /** Application ID of the application on which the event was performed.
       */
      public java.lang.Long getApplicationId() {
        return applicationId;
      }

      /** Application ID of the application on which the event was performed. */
      public List setApplicationId(java.lang.Long applicationId) {
        this.applicationId = applicationId;
        return this;
      }

      /** Email address of the user who performed the action. */
      @com.google.api.client.util.Key
      private java.lang.String actorEmail;

      /** Email address of the user who performed the action.
       */
      public java.lang.String getActorEmail() {
        return actorEmail;
      }

      /** Email address of the user who performed the action. */
      public List setActorEmail(java.lang.String actorEmail) {
        this.actorEmail = actorEmail;
        return this;
      }

      /**
       * Application ID of the application which interacted on behalf of the user while performing
       * the event.
       */
      @com.google.api.client.util.Key
      private java.lang.Long actorApplicationId;

      /** Application ID of the application which interacted on behalf of the user while performing the
     event.
       */
      public java.lang.Long getActorApplicationId() {
        return actorApplicationId;
      }

      /**
       * Application ID of the application which interacted on behalf of the user while performing
       * the event.
       */
      public List setActorApplicationId(java.lang.Long actorApplicationId) {
        this.actorApplicationId = actorApplicationId;
        return this;
      }

      /**
       * IP Address of host where the event was performed. Supports both IPv4 and IPv6 addresses.
       */
      @com.google.api.client.util.Key
      private java.lang.String actorIpAddress;

      /** IP Address of host where the event was performed. Supports both IPv4 and IPv6 addresses.
       */
      public java.lang.String getActorIpAddress() {
        return actorIpAddress;
      }

      /**
       * IP Address of host where the event was performed. Supports both IPv4 and IPv6 addresses.
       */
      public List setActorIpAddress(java.lang.String actorIpAddress) {
        this.actorIpAddress = actorIpAddress;
        return this;
      }

      /** Type of the caller. */
      @com.google.api.client.util.Key
      private java.lang.String caller;

      /** Type of the caller.
       */
      public java.lang.String getCaller() {
        return caller;
      }

      /** Type of the caller. */
      public List setCaller(java.lang.String caller) {
        this.caller = caller;
        return this;
      }

      /** Number of activity records to be shown in each page. */
      @com.google.api.client.util.Key
      private java.lang.Integer maxResults;

      /** Number of activity records to be shown in each page.

     [minimum: 1] [maximum: 1000]
       */
      public java.lang.Integer getMaxResults() {
        return maxResults;
      }

      /** Number of activity records to be shown in each page. */
      public List setMaxResults(java.lang.Integer maxResults) {
        this.maxResults = maxResults;
        return this;
      }

      /** Name of the event being queried. */
      @com.google.api.client.util.Key
      private java.lang.String eventName;

      /** Name of the event being queried.
       */
      public java.lang.String getEventName() {
        return eventName;
      }

      /** Name of the event being queried. */
      public List setEventName(java.lang.String eventName) {
        this.eventName = eventName;
        return this;
      }

      /** Return events which occured at or after this time. */
      @com.google.api.client.util.Key
      private java.lang.String startTime;

      /** Return events which occured at or after this time.
       */
      public java.lang.String getStartTime() {
        return startTime;
      }

      /** Return events which occured at or after this time. */
      public List setStartTime(java.lang.String startTime) {
        this.startTime = startTime;
        return this;
      }

      /** Return events which occured at or before this time. */
      @com.google.api.client.util.Key
      private java.lang.String endTime;

      /** Return events which occured at or before this time.
       */
      public java.lang.String getEndTime() {
        return endTime;
      }

      /** Return events which occured at or before this time. */
      public List setEndTime(java.lang.String endTime) {
        this.endTime = endTime;
        return this;
      }

      /** Next page URL. */
      @com.google.api.client.util.Key
      private java.lang.String continuationToken;

      /** Next page URL.
       */
      public java.lang.String getContinuationToken() {
        return continuationToken;
      }

      /** Next page URL. */
      public List setContinuationToken(java.lang.String continuationToken) {
        this.continuationToken = continuationToken;
        return this;
      }

      @Override
      public List set(String parameterName, Object value) {
        return (List) super.set(parameterName, value);
      }
    }

  }

  /**
   * Builder for {@link Audit}.
   *
   * <p>
   * Implementation is not thread-safe.
   * </p>
   *
   * @since 1.3.0
   */
  public static final class Builder extends com.google.api.client.googleapis.services.json.AbstractGoogleJsonClient.Builder {

    /**
     * Returns an instance of a new builder.
     *
     * @param transport HTTP transport, which should normally be:
     *        <ul>
     *        <li>Google App Engine:
     *        {@code com.google.api.client.extensions.appengine.http.UrlFetchTransport}</li>
     *        <li>Android: {@code newCompatibleTransport} from
     *        {@code com.google.api.client.extensions.android.http.AndroidHttp}</li>
     *        <li>Java: {@link com.google.api.client.googleapis.javanet.GoogleNetHttpTransport#newTrustedTransport()}
     *        </li>
     *        </ul>
     * @param jsonFactory JSON factory, which may be:
     *        <ul>
     *        <li>Jackson: {@code com.google.api.client.json.jackson2.JacksonFactory}</li>
     *        <li>Google GSON: {@code com.google.api.client.json.gson.GsonFactory}</li>
     *        <li>Android Honeycomb or higher:
     *        {@code com.google.api.client.extensions.android.json.AndroidJsonFactory}</li>
     *        </ul>
     * @param httpRequestInitializer HTTP request initializer or {@code null} for none
     * @since 1.7
     */
    public Builder(com.google.api.client.http.HttpTransport transport, com.google.api.client.json.JsonFactory jsonFactory,
        com.google.api.client.http.HttpRequestInitializer httpRequestInitializer) {
      super(
          transport,
          jsonFactory,
          DEFAULT_ROOT_URL,
          DEFAULT_SERVICE_PATH,
          httpRequestInitializer,
          false);
    }

    /** Builds a new instance of {@link Audit}. */
    @Override
    public Audit build() {
      return new Audit(this);
    }

    @Override
    public Builder setRootUrl(String rootUrl) {
      return (Builder) super.setRootUrl(rootUrl);
    }

    @Override
    public Builder setServicePath(String servicePath) {
      return (Builder) super.setServicePath(servicePath);
    }

    @Override
    public Builder setHttpRequestInitializer(com.google.api.client.http.HttpRequestInitializer httpRequestInitializer) {
      return (Builder) super.setHttpRequestInitializer(httpRequestInitializer);
    }

    @Override
    public Builder setApplicationName(String applicationName) {
      return (Builder) super.setApplicationName(applicationName);
    }

    @Override
    public Builder setSuppressPatternChecks(boolean suppressPatternChecks) {
      return (Builder) super.setSuppressPatternChecks(suppressPatternChecks);
    }

    @Override
    public Builder setSuppressRequiredParameterChecks(boolean suppressRequiredParameterChecks) {
      return (Builder) super.setSuppressRequiredParameterChecks(suppressRequiredParameterChecks);
    }

    @Override
    public Builder setSuppressAllChecks(boolean suppressAllChecks) {
      return (Builder) super.setSuppressAllChecks(suppressAllChecks);
    }

    /**
     * Set the {@link AuditRequestInitializer}.
     *
     * @since 1.12
     */
    public Builder setAuditRequestInitializer(
        AuditRequestInitializer auditRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(auditRequestInitializer);
    }

    @Override
    public Builder setGoogleClientRequestInitializer(
        com.google.api.client.googleapis.services.GoogleClientRequestInitializer googleClientRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(googleClientRequestInitializer);
    }
  }
}
